#
# spec file for package wrk
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wrk
Version:        4.2.0
Release:        2.1
Summary:        Modern HTTP benchmarking tool
License:        Apache-2.0
Group:          Productivity/Networking/Web/Utilities
URL:            https://github.com/wg/wrk
Source:         https://github.com/wg/wrk/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         wrk-4.2.0_distrofixes.patch
Patch1:         reproducible.patch
BuildRequires:  luajit-devel
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  pkgconfig(openssl)
ExcludeArch:    aarch64 ppc ppc64 ppc64le

%description
wrk is a modern HTTP benchmarking tool capable of generating significant
load when run on a single multi-core CPU. It combines a multithreaded
design with scalable event notification systems such as epoll and kqueue.

An optional LuaJIT script can perform HTTP request generation, response
processing, and custom reporting. Several example scripts are located in
scripts.

%prep
%autosetup -p1

%build
%make_build OPTFLAGS="%{optflags}" WITH_OPENSSL=%{_prefix}

%install
install -D -m 0755 wrk %{buildroot}%{_bindir}/wrk

%files
%license LICENSE
%doc README.md NOTICE
%doc scripts/
%{_bindir}/wrk

%changelog
* Fri Mar  7 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to create deterministic lua bytecode
- use system luajit to have the 'd' (deterministic) option available
* Tue Jan 10 2023 Andrea Manzini <andrea.manzini@suse.com>
- removed wrk-3.1.2_distrofixes.patch
- added wrk-4.2.0_distrofixes.patch
- update to 4.2.0:
  * upgrade openssl to 1.1.1i
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.1.0:
  * define _DEFAULT_SOURCE on linux
* Wed Apr 27 2016 mpluskal@suse.com
- Update to 4.0.2
  * Send hostname using TLS SNI.
  * Add optional WITH_OPENSSL and WITH_LUAJIT to use system libs.
  * Bundle OpenSSL 1.0.2.
  * delay() can return milliseconds to delay sending next request.
- Use pretty source name
- Refresh wrk-3.1.2_distrofixes.patch
* Mon Jan 25 2016 mpluskal@suse.com
- Install to /usr/bin (boo#963355)
* Mon Aug  3 2015 normand@linux.vnet.ibm.com
- Add ExcludeArch for aarch64 ppc ppc64 ppc64le
* Fri Apr 17 2015 mpluskal@suse.com
- Use url for source
- Update to version 4.0.1
  * The wrk global variable is the only global defined by default.
  * wrk.init() calls the global init(), remove calls to wrk.init().
  * Add wrk.lookup(host, port) and wrk.connect(addr) functions.
  * Add setup phase that calls the global setup() for each thread.
  * Allow assignment to thread.addr to specify the server address.
  * Add thread:set(name, value), thread:get(name), and thread:stop().
  * Record latency for every request instead of random samples.
  * Latency and requests in done() are now callable, not indexable.
  * Only record timeouts when a response is actually received.
  * Remove calibration phase and record rate at fixed interval.
  * Improve correction of coordinated omission.
* Tue Mar 10 2015 mrueckert@suse.de
- initial package
